Index: client/crashpad_info.h |
diff --git a/client/crashpad_info.h b/client/crashpad_info.h |
index 57ea4eb33af9e2613fbeb1b1c84fe9a95fe1b522..d9d239c442c4027bd5f5cb5bf657d908e93d4100 100644 |
--- a/client/crashpad_info.h |
+++ b/client/crashpad_info.h |
@@ -99,10 +99,15 @@ struct CrashpadInfo { |
} |
#if defined(OS_WIN) |
- //! \brief Save an EXCEPTION_POINTERS record for the crash handler. |
+ //! \brief Save the crashing thread ID for the crash handler. |
+ void set_thread_id(DWORD thread_id) { thread_id_ = thread_id; } |
+ DWORD thread_id() const { return thread_id_; } |
+ |
+ //! \brief Save an `EXCEPTION_POINTERS` record for the crash handler. |
void set_exception_pointers(EXCEPTION_POINTERS* exception_pointers) { |
exception_pointers_ = exception_pointers; |
} |
+ EXCEPTION_POINTERS* exception_pointers() const { return exception_pointers_; } |
#endif // OS_WIN |
enum : uint32_t { |
@@ -130,6 +135,7 @@ struct CrashpadInfo { |
#if defined(OS_WIN) |
EXCEPTION_POINTERS* exception_pointers_; |
+ DWORD thread_id_; |
#endif // OS_WIN |
#if defined(__clang__) |